@@ -44,6 +44,16 @@ StatusHildon::StatusHildon()
   dbus_connection_add_filter(GetDBusConnection(),DBusMsgHandler,this,NULL);
 }
 
+std::string StatusHildon::GetDefaultInterface() const
+{
+  if (StatusLinux::GetDefaultInterface().empty()) {
+    return "wlan0";
+  }
+  else {
+    return StatusLinux::GetDefaultInterface();
+  }
+}
+
 DBusConnection* StatusHildon::GetDBusConnection()
 {
   return dynamic_cast<Lum::OS::X11::Display*>(Lum::OS::display)->dbusSystem;
@@ -232,6 +242,8 @@ bool StatusHildon::HandleMessage(DBusConnection *connection, DBusMessage *msg)
     }
   }
 
+  Lum::OS::display->QueueActionForEventLoop(networksChangedAction);
+
   return true;
 }
 
