@@ -33,6 +33,7 @@
 #include <Lum/OS/Main.h>
 
 #include <Lum/AppInfo.h>
+#include <Lum/Boolean.h>
 #include <Lum/Button.h>
 #include <Lum/Dialog.h>
 #include <Lum/FuelGauge.h>
@@ -41,7 +42,6 @@
 #include <Lum/Menu.h>
 #include <Lum/Panel.h>
 #include <Lum/Slider.h>
-#include <Lum/Space.h>
 #include <Lum/Tab.h>
 #include <Lum/Table.h>
 #include <Lum/Text.h>
@@ -79,6 +79,7 @@ private:
 
   Lum::Model::ListTableRef tableModel;
 
+  Lum::Model::BooleanRef   scanForNetworks;
   Lum::Model::ActionRef    powerSavingOnAction;
   Lum::Model::ActionRef    powerSavingOffAction;
 
@@ -102,14 +103,27 @@ private:
   {
     Lum::TextValue *textView;
 
-    textView=new Lum::TextValue();
-    textView->SetFlex(true,false);
+    textView=Lum::TextValue::Create(model,Lum::TextValue::left,true,false);
     textView->SetWidth(Lum::Base::Size::stdCharWidth,size);
-    textView->SetModel(model);
 
     return textView;
   }
 
+  void ParseArguments()
+  {
+    size_t i=0;
+
+    while (i<Lum::OS::display->GetArgCount()) {
+      if (Lum::OS::display->GetArg(i)==L"-d" &&
+          i+1<Lum::OS::display->GetArgCount()) {
+        i++;
+        status.SetDefaultInterface(Lum::Base::WStringToString(Lum::OS::display->GetArg(i)));
+      }
+
+      i++;
+    }
+  }
+
   void RequestStatus()
   {
     Lum::OS::display->RemoveTimer(statusTimer);
@@ -125,10 +139,15 @@ private:
     }
   }
 
-  void RequestNetworks()
+  void CancelNetworks()
   {
     Lum::OS::display->RemoveTimer(networksTimer);
     Lum::OS::display->RemoveTimer(networksErrorTimer);
+  }
+
+  void RequestNetworks()
+  {
+    CancelNetworks();
 
     if (status.SupportsNetworkRetrieval()) {
       if (status.UpdateNetworks()) {
@@ -139,7 +158,6 @@ private:
         Lum::OS::display->AddTimer(NETWORK_REFRESH,0,networksTimer);
       }
     }
-
   }
 
   void UpdateStatus()
@@ -333,7 +351,8 @@ public:
     channel(new Lum::Model::String()),
     powerSaving(new Lum::Model::Boolean()),
     refreshTime(new Lum::Model::Int(5)),
-    tableModel(new Lum::Model::ListTable(3)),
+    tableModel(new Lum::Model::ListTable()),
+    scanForNetworks(new Lum::Model::Boolean(false)),
     powerSavingOnAction(new Lum::Model::Action()),
     powerSavingOffAction(new Lum::Model::Action()),
     statusTimer(new Lum::Model::Action()),
@@ -347,6 +366,7 @@ public:
 
     powerSaving->Disable();
 
+    Observe(scanForNetworks);
     Observe(powerSavingOnAction);
     Observe(powerSavingOffAction);
 
@@ -364,63 +384,38 @@ public:
 
   virtual void PreInit()
   {
-    Lum::FuelGauge   *fuelgauge;
     Lum::Label       *label;
-    Lum::LED         *led;
     Lum::Panel       *hPanel,*hPanel2;
     Lum::Slider      *slider;
     Lum::Tab         *tab;
 
     std::wstring     tmp;
 
-    std::cout << "Bla" << std::endl;
-    tab=new Lum::Tab();
-    tab->SetFlex(true,true);
+    tab=Lum::Tab::Create(true,true);
 
-    hPanel=new Lum::HPanel();
-    hPanel->SetFlex(true,true);
-
-    label=new Lum::Label();
-    label->SetFlex(true,true);
+    hPanel=Lum::HPanel::Create(true,true);
 
+    label=Lum::Label::Create(true,true);
     label->AddLabel(L"ESSID:",CreateTextValue(essid,32));
     label->AddLabel(L"Chanel:",CreateTextValue(channel,2));
     label->AddLabel(L"Type:",CreateTextValue(type,32));
     label->AddLabel(L"AP:",CreateTextValue(accesspoint,17));
     label->AddLabel(L"Client:",CreateTextValue(client,28));
-
-    fuelgauge=new Lum::FuelGauge();
-    fuelgauge->SetFlex(true,false);
-    fuelgauge->SetModel(quality);
-    label->AddLabel(L"Quality:",fuelgauge);
-
+    label->AddLabel(L"Quality:",Lum::FuelGauge::Create(quality,true,false));
     label->AddLabel(L"SNR:",CreateTextValue(signalNoise,18));
 
-    hPanel2=new Lum::HPanel();
-
-    led=new Lum::LED();
-    led->SetModel(powerSaving);
-    hPanel2->Add(led);
+    hPanel2=Lum::HPanel::Create();
+    hPanel2->Add(new Lum::LED(powerSaving));
 
     if (status.CanChangePowerSaving()) {
-      Lum::Button *button;
-
-      hPanel2->Add(new Lum::HSpace());
-
-      button=new Lum::Button(L"_On");
-      button->SetModel(powerSavingOnAction);
-      hPanel2->Add(button);
-
-      hPanel2->Add(new Lum::HSpace());
-
-      button=new Lum::Button(L"O_ff");
-      button->SetModel(powerSavingOffAction);
-      hPanel2->Add(button);
+      hPanel2->AddSpace();
+      hPanel2->Add(Lum::Button::Create(L"_On",powerSavingOnAction));
+      hPanel2->AddSpace();
+      hPanel2->Add(Lum::Button::Create(L"O_ff",powerSavingOffAction));
     }
 
     label->AddLabel(L"Power saving:",hPanel2);
 
-
     slider=new Lum::HSlider();
     slider->SetFlex(true,false);
     slider->SetScale(true);
@@ -432,10 +427,16 @@ public:
     tab->Add(L"Current",hPanel);
 
     if (status.SupportsNetworkRetrieval()) {
+      Lum::Panel                         *panel;
       Lum::Table                         *table;
       Lum::Model::HeaderRef              headerModel;
       Lum::Model::SingleLineSelectionRef selection;
 
+      panel=Lum::VPanel::Create(true,true);
+      panel->Add(Lum::Label::Create(true,false)
+                 ->AddLabel(L"Scan for networks:",Lum::Boolean::Create(scanForNetworks)));
+      panel->AddSpace();
+
       selection=new Lum::Model::SingleLineSelection;
 
       headerModel=new Lum::Model::HeaderImpl();
@@ -454,7 +455,10 @@ public:
       table->GetTableView()->SetMinHeight(Lum::Base::Size::stdCharHeight,4);
       table->GetTableView()->SetAutoFitColumns(true);
       table->GetTableView()->SetAutoHSize(true);
-      tab->Add(L"All",table);
+
+      panel->Add(table);
+
+      tab->Add(L"All",panel);
     }
 
     SetMain(tab);
@@ -477,11 +481,18 @@ public:
   void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
   {
     if (model==GetOpenedAction() && GetOpenedAction()->IsFinished()) {
+      ParseArguments();
       UpdateStatus();
       RequestStatus();
-
-      UpdateNetworks();
-      RequestNetworks();
+    }
+    else if (model==scanForNetworks) {
+      if (*scanForNetworks) {
+        RequestNetworks();
+      }
+      else {
+        CancelNetworks();
+        UpdateNetworks();
+      }
     }
     else if (model==powerSavingOnAction && powerSavingOnAction->IsFinished()) {
       status.SetPowerSaving(true);
